## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment  = "#>",
  eval     = FALSE
)

## ----setup--------------------------------------------------------------------
# library(bs4Dashkit)

## -----------------------------------------------------------------------------
# options(
#   bs4Dashkit.sidebar.collapsed = "icon-only",
#   bs4Dashkit.sidebar.expanded  = "icon-text",
#   bs4Dashkit.brand_divider     = TRUE,
#   bs4Dashkit.theme_preset      = "professional",
#   bs4Dashkit.accent            = "#2f6f8f",
#   bs4Dashkit.debug             = FALSE
# )
# 

## -----------------------------------------------------------------------------
# ttl <- dash_titles(
#   brand_text = "Dashboard",
#   icon       = icon("project-diagram")
# )
# 
# ui <- bs4DashPage(
#   title  = ttl$app_name,
#   header = bs4DashNavbar(title = ttl$brand),
#   sidebar = bs4DashSidebar(),
#   body = bs4DashBody(
#     use_bs4Dashkit_core(ttl)
#   )
# )
# 

## -----------------------------------------------------------------------------
# ttl <- dash_titles(
#   brand_text     = "Special App",
#   icon           = icon("star"),
#   collapsed      = "icon-text",
#   collapsed_text = "SAP",
#   brand_divider  = FALSE
# )
# 
# body <- bs4DashBody(
#   use_bs4Dashkit_core(ttl, preset = "modern", accent = "#6b2f8f")
# )
# 

## -----------------------------------------------------------------------------
# getOption("bs4Dashkit.sidebar.collapsed")
# getOption("bs4Dashkit.sidebar.expanded")
# getOption("bs4Dashkit.brand_divider")
# getOption("bs4Dashkit.theme_preset")
# getOption("bs4Dashkit.accent")
# getOption("bs4Dashkit.debug")
# 

## -----------------------------------------------------------------------------
# options(
#   bs4Dashkit.sidebar.collapsed = NULL,
#   bs4Dashkit.sidebar.expanded  = NULL,
#   bs4Dashkit.brand_divider     = NULL,
#   bs4Dashkit.theme_preset      = NULL,
#   bs4Dashkit.accent            = NULL,
#   bs4Dashkit.debug             = NULL
# )
# 

